## See https://packaging.python.org/guides/single-sourcing-package-version/

'''A collection of functions for ipython use in the classroom

   -------   Time-stamp: <2021-01-22 15:47:35 hedfp>   ------  '''


__version__ = "0.0b2.dev26" # X.YaN.devM format for now

